@@ -1,6 +1,5 @@
 from rpy2.robjects.robject import RObjectMixin, RObject
 import rpy2.rinterface as rinterface
-#import rpy2.robjects.conversion as conversion
 from . import conversion
 
 import rpy2.rlike.container as rlc
@@ -29,7 +28,9 @@ else:
 
 globalenv_ri = rinterface.globalenv
 baseenv_ri = rinterface.baseenv
-utils_ri = rinterface.baseenv['as.environment'](rinterface.StrSexpVector(("package:utils", )))
+r_concat = baseenv_ri['c']
+as_character = baseenv_ri['as.character']
+utils_ri = baseenv_ri['as.environment'](rinterface.StrSexpVector(("package:utils", )))
 
 class ExtractDelegator(object):
     """ Delegate the R 'extraction' ("[") and 'replacement' ("[<-")
@@ -723,7 +724,38 @@ class DateVector(FloatVector):
 
 class POSIXt(object):
     """ POSIX time vector. This is an abstract class. """
-    pass
+
+    def repr_format_elt(self, elt, max_width = 12):        
+        max_width = int(max_width)
+        str_elt = str(elt)
+        if len(str_elt) < max_width:
+            res = elt
+        else:
+            res = "%s..." % str_elt[ : (max_width - 3)]
+        return res
+
+    
+    def _iter_formatted(self, max_items=9):
+        format_elt = self.repr_format_elt
+        l = len(self)
+        half_items = max_items // 2
+        max_width = math.floor(52 / l)
+        if l == 0:
+            return
+        elif l < max_items:
+            str_vec = StrVector(as_character(self))
+        else:
+            str_vec = r_concat(
+                as_character(
+                  self.rx(IntSexpVector(tuple(range(1, (half_items-1)))))
+                ),
+                StrSexpVector(['...']),
+                as_character(
+                  self.rx(IntSexpVector(tuple(range((l-half_items), l))))
+                ))
+        for str_elt in str_vec:
+            yield self.repr_format_elt(str_elt)
+
 
 class POSIXlt(POSIXt, Vector):
     """ Representation of dates with a 9-component structure
@@ -757,6 +789,7 @@ class POSIXlt(POSIXt, Vector):
         # (and yes, this is confusing)
         tmp = self.rx2(i-1)
         return struct_time(*tuple(tmp))
+
         
 class POSIXct(POSIXt, FloatVector):
     """ Representation of dates as seconds since Epoch.
@@ -1112,9 +1145,9 @@ class DataFrame(ListVector):
                 elements.append(tuple(e._iter_formatted()))
             else:
                 elements.append(['...',] * len(elements[-1]))
-       
+        
         d = {'column_names': names,
-             'rows': tuple(range(len(elements))),
+             'rows': range(len(elements[0]) if len(elements) else 0),
              'columns': tuple(range(len(names))),
              'nrows': self.nrow,
              'ncolumns': self.ncol,
